summaryrefslogtreecommitdiff
path: root/indra/newview/llpanelplaceinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llpanelplaceinfo.h')
-rw-r--r--indra/newview/llpanelplaceinfo.h21
1 files changed, 8 insertions, 13 deletions
diff --git a/indra/newview/llpanelplaceinfo.h b/indra/newview/llpanelplaceinfo.h
index 60f35cd0c1..32ae4334aa 100644
--- a/indra/newview/llpanelplaceinfo.h
+++ b/indra/newview/llpanelplaceinfo.h
@@ -42,17 +42,17 @@
#include "llpanelmedia.h"
#include "llremoteparcelrequest.h"
-#include "llviewerparcelmgr.h"
class LLButton;
class LLInventoryItem;
class LLLineEditor;
-class LLParcelSelection;
+class LLParcel;
class LLTextBox;
class LLTextEditor;
class LLTextureCtrl;
+class LLViewerRegion;
-class LLPanelPlaceInfo : public LLPanel, LLRemoteParcelInfoObserver, LLParcelObserver
+class LLPanelPlaceInfo : public LLPanel, LLRemoteParcelInfoObserver
{
public:
enum INFO_TYPE
@@ -99,16 +99,14 @@ public:
// Displays information about a remote parcel.
// Sends a request to the server.
- void displayParcelInfo(const LLVector3& pos_region,
- const LLUUID& region_id,
+ void displayParcelInfo(const LLUUID& region_id,
const LLVector3d& pos_global);
// Displays information about the parcel the agent is currently on
// without sending a request to the server.
- void displayAgentParcelInfo();
-
- // Called on parcel selection change by LLViewerParcelMgr.
- /*virtual*/ void changed();
+ void displaySelectedParcelInfo(LLParcel* parcel,
+ LLViewerRegion* region,
+ const LLVector3d& pos_global);
void updateEstateName(const std::string& name);
void updateEstateOwnerName(const std::string& name);
@@ -135,7 +133,6 @@ private:
LLUUID mParcelID;
LLUUID mRequestedID;
LLUUID mLandmarkID;
- LLVector3 mPosRegion;
std::string mCurrentTitle;
S32 mMinHeight;
INFO_TYPE mInfoType;
@@ -186,8 +183,6 @@ private:
LLPanel* mScrollingPanel;
LLPanel* mInfoPanel;
LLMediaPanel* mMediaPanel;
-
- LLSafeHandle<LLParcelSelection> mParcel;
};
#endif // LL_LLPANELPLACEINFO_H
@@ -99,16 +99,14 @@ public:
const LLVector3d& pos_global);
- // Displays information about the parcel the agent is currently on
+ // Displays information about the currently selected parcel
// without sending a request to the server.